@@ -38,12 +38,30 @@ class ITagHelperSettingsSchema(interface.Interface):
         default=u'http://opensilcc.com/api/tag',
         )
 
+    alchemy_api_key = schema.TextLine(
+        title=u'AlchemyAPI Key',
+        description=u'API Key can be obtained at http://www.alchemyapi.com/api/register.html',
+        required=False,
+        readonly=False,
+        default=None,
+        )
+
+
+
     use_remote_url = schema.Bool(
         title=u'Use remote url',
         description=u'''If the content item has a remote url
                         extract the tags from there rather than
-                        from the local content (Yahoo and tagthe.net only)''',
+                        from the local content (Yahoo, AlchemyAPI and tagthe.net only)''',
         required=False,
         readonly=False,
         default=True,
         )
+
+    webservices = schema.List(
+        title = _(u'Use webservices'),
+        required = False,
+        default = [],
+        description = _(u"List the webservices you want to use for tagging"),
+        value_type = schema.Choice(title=_(u"webservices"),
+                    source="collective.taghelper.webservices"))
